## sphinxbio: A [Sphinx Bio](https://www.sphinxbio.com/) Python client
 Python Library

[![PyPI](https://img.shields.io/pypi/v/sphinxbio)](https://pypi.org/project/sphinxbio/)
[![fern shield](https://img.shields.io/badge/%F0%9F%8C%BF-SDK%20generated%20by%20Fern-brightgreen)](https://github.com/fern-api/fern)


### Installation
```bash
pip install sphinxbio   # or poetry install, etc.
```

